@@ -118,7 +118,7 @@ for i, decal in ipairs (textures.decals) do
 				  billiards.ballradius^3),
 			         billiards.ballradius),
 
-      lethargy = {0.01, 0.01, 10, 0},
+      lethargy = {0.01, 0.1, 2, 0},
 
       isball = true,
 
@@ -230,10 +230,6 @@ for i, decal in ipairs (textures.decals) do
    }
 end
 
-for _, ball in pairs (bodies.balls) do
-   physics.addforce (ball, {5 * math.random(), 5 * math.random(), 0})
-end 
-
 bodies.cueball = bodies.balls[1]
 
 -- Add them to the scene.
@@ -275,6 +271,14 @@ graph.gear = bodies.system {
    unpack (bodies.balls)
 }
 
+-- Perturb the opening position slightly.
+
+for _, ball in ipairs (bodies.balls) do
+   physics.addforce (ball, {2 * (math.random() - 0.5),
+			    2 * (math.random() - 0.5),
+			    0})
+end
+
 -- Now for the simulation and control logic.
 
 billiards.looking.newshot = function ()
