@@ -19,15 +19,11 @@
 
 #include <lua.h>
 #include <ode/ode.h>
-#include "body.h"
+#include "space.h"
 
-@interface Environment: Node {
+@interface Environment: Space {
 }
 
--(dSpaceID) space;
--(void) addBody: (id) node;
--(void) removeBody: (id) node;
-
 @end
 
 #endif
