@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _QUAD_H_
-#define _QUAD_H_
+#ifndef _FRAME_H_
+#define _FRAME_H_
 
 #include <lua.h>
 #include "widget.h"
