@@ -26,11 +26,13 @@
     char *key;
 }
 
--(id)parent;
--(id)children;
--(id)brother;
--(id)sister;
+-(id) parent;
+-(id) children;
+-(id) brother;
+-(id) sister;
 -(id) root;
+-(char *) key;
+-(void) adoptedBy: (Item *) parent;
 -(void) adopt: (Item *)child named: (const char *)key;
 -(void) renounce: (Item *)child;
 
