@@ -115,7 +115,7 @@ static void callback (void *data, dGeomID a, dGeomID b)
 		    contacts[j].fdir1[1] = delta[1] - ndotdelta * n[1];
 		    contacts[j].fdir1[2] = delta[2] - ndotdelta * n[2];
 
-		    dNormalize3(contacts[j].fdir1);
+		    dSafeNormalize3(contacts[j].fdir1);
 		
 		    j += 1;
 		}
@@ -196,6 +196,10 @@ static void callback (void *data, dGeomID a, dGeomID b)
 		    contacts[i].surface.bounce = epsilon;
 		    contacts[i].surface.bounce_vel = 0.01;
 
+/* 		    if (dGeomGetClass (b) == dCCylinderClass || */
+/* 			dGeomGetClass (a) == dCCylinderClass) { */
+/* 		    } */
+		    
 /* 		    if (dGeomGetClass (b) == dTriMeshClass || */
 /* 			dGeomGetClass (a) == dTriMeshClass) { */
 /* 			float ks = 20750, kd = 1000; */
@@ -1116,7 +1120,7 @@ int main(int argc, char **argv)
     
     lua_close (_L);
 
-    /* Destroy the adui context. */
+    /* Destroy the audio context. */
     
     if (audio) {
 	alcDestroyContext (audio);
