@@ -17,9 +17,9 @@
 #ifndef _ROW_H_
 #define _ROW_H_
 
-#include "container.h"
+#include "widget.h"
 
-@interface Row: Container {
+@interface Row: Widget {
 }
 @end
 
