@@ -22,11 +22,21 @@
 #include "node.h"
 
 @interface Source: Node {
-    double tick;
     ALuint index;
+    ALenum state;
+    ALuint name, frequency;
+
+    double tick;
+    int size, finished;
 }
 
 -(ALint) index;
+-(Source *) initWithSamples: (ALshort *) samples
+                     ofSize: (int) n
+		atFrequency: (int) f;
+-(void) freeBuffers;
+-(int) length;
+-(int) frequency;
 
 @end
 
