@@ -21,12 +21,13 @@
 #include "widget.h"
 
 @interface String: Widget {
+    id face;
+    
     GLuint texture;
-    float minimum[2];
+    int reference, texels[2];
 }
 
--(void) freeTexture;
--(String *)initFromPixels: (unsigned char *) pixels ofSize: (int[2]) size;
+-(String *)initFromFace: (id) face;
 @end
 
 #endif
